# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from .....schema_classes import InferredDescriptionClass
from .....schema_classes import InferredGlossaryTermsClass
from .....schema_classes import InferredMetadataClass
from .....schema_classes import InferredMetadataSourceClass
from .....schema_classes import InferredNeighborClass
from .....schema_classes import InferredNeighborsClass
from .....schema_classes import InferredOwnersClass
from .....schema_classes import InferredTagsClass
from .....schema_classes import SchemaFieldInferredMetadataClass
from .....schema_classes import SchemaFieldInferredNeighborsClass
from .....schema_classes import SchemaFieldsInferredMetadataClass
from .....schema_classes import SchemaFieldsInferredNeighborsClass
from .....schema_classes import SimilarityFactorClass


InferredDescription = InferredDescriptionClass
InferredGlossaryTerms = InferredGlossaryTermsClass
InferredMetadata = InferredMetadataClass
InferredMetadataSource = InferredMetadataSourceClass
InferredNeighbor = InferredNeighborClass
InferredNeighbors = InferredNeighborsClass
InferredOwners = InferredOwnersClass
InferredTags = InferredTagsClass
SchemaFieldInferredMetadata = SchemaFieldInferredMetadataClass
SchemaFieldInferredNeighbors = SchemaFieldInferredNeighborsClass
SchemaFieldsInferredMetadata = SchemaFieldsInferredMetadataClass
SchemaFieldsInferredNeighbors = SchemaFieldsInferredNeighborsClass
SimilarityFactor = SimilarityFactorClass

# fmt: on
