# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from .....schema_classes import AiInferenceMetadataClass
from .....schema_classes import EntityInferenceMetadataClass
from .....schema_classes import GlossaryTermsInferenceMetadataClass
from .....schema_classes import InferenceGroupMetadataClass
from .....schema_classes import InferenceMetadataClass


AiInferenceMetadata = AiInferenceMetadataClass
EntityInferenceMetadata = EntityInferenceMetadataClass
GlossaryTermsInferenceMetadata = GlossaryTermsInferenceMetadataClass
InferenceGroupMetadata = InferenceGroupMetadataClass
InferenceMetadata = InferenceMetadataClass

# fmt: on
